<?php

namespace Drupal\ww_publish\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\Form\FormStateInterface;

/**
 * SNS message entity form for ww_publish.
 */
class SnsMessageForm extends EntityForm {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    // Prepare the form.
    $form = parent::form($form, $form_state);

    $form['name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name of the SNS message'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
      '#default_value' => $this->entity->name,
      '#description' => $this->t('The name is used to generate the ID.'),
    ];
    $form['id'] = [
      '#type' => 'machine_name',
      '#disabled' => !$this->entity->isNew(),
      '#default_value' => $this->entity->id(),
      '#machine_name' => [
        'exists' => [$this, 'exists'],
        'source' => ['name'],
      ],
    ];

    $form['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('URL'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
      '#default_value' => $this->entity->url,
    ];
    $form['metadata_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Metadata URL'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
      '#default_value' => $this->entity->metadata_url,
    ];
    $form['article_json_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Article JSON URL'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
      '#default_value' => $this->entity->article_json_url,
    ];
    $form['tenant_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tenant ID'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
      '#default_value' => $this->entity->tenant_id,
    ];
    $form['brand'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Brand'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
      '#default_value' => $this->entity->brand,
    ];

    $form['executed'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Executed'),
      '#default_value' => $this->entity->executed,
    ];

    // Return the form.
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    // Save the template and display the status message.
    try {
      $this->entity->save();
    }
    catch (EntityStorageException $exception) {
      $this->logger('ww_publish')->error('The SNS message %id was not saved.', ['%id' => $this->entity->id()]);
      $this->messenger()->addError($this->t('The SNS message %id was not saved.', ['%id' => $this->entity->id()]));
    }
    // Redirect to the proper url.
    $form_state->setRedirect('entity.ww_publish_sns_message');
  }

  /**
   * Checks if the SNS message exists.
   *
   * @param string $id
   *   Machine name (ID) of the SNS message.
   *
   * @return bool
   *   Returns true, if the SNS message exist.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function exists($id) {
    $storage = $this->entityTypeManager->getStorage('ww_publish_sns_message');
    return (bool) $storage->getQuery()->condition('id', $id)->execute();
  }

}
