<?php

namespace Drupal\ww_publish;

class Job {

  /**
   * Configuration of the ww_publish module.
   *
   * @var \Drupal\Core\Config\Config
   */
  private $config;

  /**
   * A logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  private $logger;

  /**
   * Constructor.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   * @param \Drupal\Core\Config\Config $config
   *   The config.
   */
  public function __construct($config, $logger) {
    $this->config = $config;
    $this->logger = $logger;
  }

  /**
   * Create or update node.
   *
   * @param $eventMessage
   *
   * @return bool
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function publishArticle($eventMessage) {

    // Get article metadata.
    $message = new Message($eventMessage);
    $articleMetadata = $message->getArticleMetadata();
    $metadata = new Metadata($articleMetadata, $this->config, $this->logger);
    $this->logger->setCurrentUser($metadata->getAuthor());
    if ($this->config->get('debug_mode'))
      $this->logger->info('Article Metadata: <pre><code>' . print_r($metadata->getMetadata(), TRUE) . '</code></pre>');

    if ($metadata->validate()) {
      $articleData = $message->getArticleJSON();
      if ($this->config->get('debug_mode'))
        $this->logger->info('Article: <pre><code>' . print_r($articleData, TRUE) . '</code></pre>');
    } else {
      $this->logger->error('The metadata could not be validated.');
      return FALSE;
    }

    $preparedFiles = $message->prepareArticleFiles();
    if ($this->config->get('debug_mode'))
      $this->logger->info('Prepared files: <pre><code>' . print_r($preparedFiles, TRUE) . '</code></pre>');

    $article = new Article($metadata, $articleData, $preparedFiles, $this->config, $this->logger);
    $article->publish();
  }

}
