<?php

namespace Drupal\ww_publish;

use \Drupal\ww_publish\Entity\TemplateEntity;

class Template {

  /**
   * Template entity.
   *
   * @var \Drupal\ww_publish\Entity\TemplateEntity
   */
  private $templateEntity;

  /**
   * A logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  private $logger;

  /**
   * Constructor.
   *
   * @param string $target
   *   Identifier of the target WoodWing Studio component.
   * @param string $type
   *   Type of the template: component, attribute.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   */
  public function __construct($target, $type, $logger) {
    $this->logger = $logger;
    $query = \Drupal::entityQuery('ww_publish_template');
    $query->condition('target', $target);
    $query->condition('type', $type);
    $templateEntityIds = $query->execute();
    if (!empty($templateEntityIds)) {
      $this->templateEntity = TemplateEntity::load(reset($templateEntityIds));
    } else {
      $this->logger->warning('No template entity found with target: ' . $target . ' and type: ' . $type . '.');
    }
  }

  /**
   * Apply template.
   *
   * @param array $parameters
   *   Parameters used in the template.
   *
   * @return string
   */
  public function apply($parameters) {
    if ($this->templateEntity) {
      $template = $this->templateEntity->template;
      foreach ($parameters as $parameter => $content) {
        $template = str_replace('{{' . $parameter . '}}', $content, $template);
      }
      return $template;
    } else {
      $this->logger->error('There is no template entity defined.');
      return '';
    }
  }

  /**
   * Is the template defined?
   *
   * @return bool
   */
  public function exist() {
    if ($this->templateEntity) {
      return TRUE;
    } else {
      return FALSE;
    }
  }
}
